#
# spec file for package cockpit-podman
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           cockpit-podman
Version:        91
Release:        2.1
Summary:        Cockpit component for Podman containers
License:        LGPL-2.1-or-later
URL:            https://github.com/cockpit-project/cockpit-podman
Source:         https://github.com/cockpit-project/cockpit-podman/archive/%{version}.tar.gz#/cockpit-podman-%{version}.tar.gz
Source10:       package-lock.json
Source11:       node_modules.spec.inc
Source12:       update_version.sh
%include %_sourcedir/node_modules.spec.inc
Patch10:        load-css-overrides.patch
Patch11:        correct-container-search.patch
BuildArch:      noarch
BuildRequires:  appstream-glib
Requires:       cockpit-bridge >= 138
Requires:       cockpit-shell >= 138
Requires:       podman >= 2.0.4
#
BuildRequires:  cockpit-devel >= 298
BuildRequires:  local-npm-registry
BuildRequires:  sassc
BuildRequires:  sed

%description
Cockpit component for managing Podman containers

%prep
%autosetup -p1
rm -r node_modules
rm -f package-lock.json
local-npm-registry %{_sourcedir} install --include=dev --ignore-scripts

%build
export PREFIX=%{_prefix}
mkdir -p pkg/lib
cp -r %{_datadir}/cockpit/devel/lib/* pkg/lib

npm run build

%install
export PREFIX=%{_prefix}
%make_install
appstream-util validate-relax --nonet %{buildroot}/%{_datadir}/metainfo/*

%if 0%{?suse_version} == 1500
sed -i -e 's#"/lib/systemd/system#"%{_unitdir}#' %{buildroot}%{_datadir}/cockpit/podman/manifest.json
%endif

%files
%doc README.md
%license LICENSE
%{_datadir}/cockpit
%{_datadir}/metainfo/*

%changelog
* Tue Nov  5 2024 Alice Brooks <alice.brooks@suse.com>
- correct-container-search.patch: Fixes issues searching containers
  bsc#1232687
* Fri Aug  9 2024 Herbert Graeber <herbert@graeber-clan.de>
- Fix systemd units folder for leap and sle (Similar issue like boo#1226541)
* Wed Jul 31 2024 Adam Majer <adam.majer@suse.de>
- New version 91. Changes since 84:
  * Implement pull option for existing images
  * Use binary http channel for podman socket for non-UTF-8 robustness
  * Stop using obsolete cockpit.utf8_{de,en}coder() API
  * Translation updates
  * Bug fixes and performance improvements
- update_version.sh: fetch package-lock.json from upstream
  instead of regenerating.
* Sun Feb 18 2024 ecsos <ecsos@opensuse.org>
- New version 84:
  * Bug fixes and stability improvements
* Wed Jan 31 2024 Adam Majer <adam.majer@suse.de>
- New version 83:
  * bug fixes and library updates
* Fri Dec 29 2023 Adam Majer <adam.majer@suse.de> - 82
- New version 82:
  * Validate fields in "Create container" dialog
  * Label Toolbox and Distrobox containers
  * Performance and stability improvements
* Fri Sep  8 2023 Adam Majer <adam.majer@suse.de> - 76
- New version 76:
  * performance and stability improvements
- deps.patch: upstreamed, dropped
* Mon Aug 21 2023 Adam Majer <adam.majer@suse.de>
- New version 74:
  * Bug fixes and translation updates
  * fixes for PatternFly 5
- deps.patch: fix dependencies
* Thu Aug  3 2023 Adam Majer <adam.majer@suse.de>
- New version 73. Changes since 70 include,
  * show time of container's latest checkpoint
  * Bug fixes and translation updates
  * Add manifest condition for the Python bridge
- 1299.patch: included in release and deleted here
* Fri Jun 16 2023 Adam Majer <adam.majer@suse.de>
- New version 70. Changes since 53 include,
  * Add ability to prune unused containers
  * Translation updates
  * Container list can be sorted
  * Custom healthcheck actions
  * Dark theme support
  * Pod CPU, memory, port and volume details
  * Create new pod group functionality
  * Show all containers by default
  * Stability and performance improvements
- load-css-overrides.patch: refreshed
- 1299.patch: fixes build with new PF5
* Tue Sep 20 2022 Adam Majer <adam.majer@suse.de>
- new version 53. Changes since 49.1 include,
  * Use NumberInput for Image Run Dialog
  * Fix events with large number of containers
  * Translation updates
  * Add Volumes and Env Variables to container details
  * Show volume permission in container integration tab
  * Allow no system users to set restart policy
  * Show image history
  * Stability and performance improvements
* Fri Jun 17 2022 Adam Majer <adam.majer@suse.de>
- load-css-overrides.patch: css overrides for better theming support
* Fri Jun 10 2022 Adam Majer <adam.majer@suse.de>
- new version 49.1
  https://github.com/cockpit-project/cockpit-podman/releases/tag/49.1
* Fri Apr 22 2022 Jacek Tomasiak <jtomasiak@suse.com>
- Remove translate-toolkit which is not available in SLE
* Mon Dec 20 2021 ecsos <ecsos@opensuse.org>
- Add source-offest to _service to fix build error in Leap.
* Fri Aug 13 2021 Ludwig Nussel <lnussel@suse.de>
- new version 33
  https://github.com/cockpit-project/cockpit-podman/releases/tag/33
- fix_dependencies.patch no longer needed
* Wed Feb 24 2021 Adam Majer <adam.majer@suse.de>
- new version 28.1
  https://github.com/cockpit-project/cockpit-podman/releases/tag/28.1
- use upstream sources without bundled and pre-built dist since
  we want to rebuild it
- use local-npm-registry for building
- fix_dependencies.patch: fix build dependencies
* Fri Jan 22 2021 Ludwig Nussel <lnussel@suse.de>
- new version 26
  https://github.com/cockpit-project/cockpit-podman/releases/tag/26
* Thu Oct 15 2020 Ludwig Nussel <lnussel@suse.de>
- new version 25
  https://cockpit-project.org/blog/cockpit-230.html
* Fri Oct  2 2020 Ludwig Nussel <lnussel@suse.de>
- new version 24
  https://cockpit-project.org/blog/cockpit-228.html
* Fri Aug 14 2020 Ludwig Nussel <lnussel@suse.de>
- initial package version 21
